@@ -2,7 +2,7 @@
 
 set -e
 
-function __compile_and_install {
+__compile_and_install() {
   cmake .. -DCMAKE_INSTALL_PREFIX=/usr
   make -j2
   make install
