@@ -5,6 +5,7 @@
 #include "../imports.h"
 #include "../gui-common.h"
 #include "../gquarks.h"
+#include "common.h"
 
 
 static GSList *parse_json_data                (const gchar          *data,
@@ -173,7 +174,7 @@ parse_json_data (const gchar *data,
             return NULL;
         }
 
-        otps = g_slist_append (otps, g_memdup (otp, sizeof (otp_t)));
+        otps = g_slist_append (otps, g_memdupX (otp, sizeof (otp_t)));
         g_free (otp);
     }
 
