@@ -64,7 +64,7 @@ guint32
 jenkins_one_at_a_time_hash (const gchar *key, gsize len)
 {
     guint32 hash, i;
-    for(hash = i = 0; i < len; ++i) {
+    for (hash = i = 0; i < len; ++i) {
         hash += key[i];
         hash += (hash << 10);
         hash ^= (hash >> 6);
@@ -98,3 +98,32 @@ json_object_get_hash (json_t *obj)
 
     return hash;
 }
+
+gchar *
+secure_strdup (const gchar *src)
+{
+    gchar *sec_buf = gcry_calloc_secure (strlen (src) + 1, 1);
+    memcpy (sec_buf, src, strlen (src) + 1);
+
+    return sec_buf;
+}
+
+
+gchar *
+g_trim_whitespace (const gchar *str)
+{
+    if (g_utf8_strlen (str, -1) == 0) {
+        return NULL;
+    }
+    gchar *sec_buf = gcry_calloc_secure (strlen (str) + 1, 1);
+    int pos = 0;
+    for (int i = 0; str[i]; i++) {
+        if (str[i] != ' ') {
+            sec_buf[pos++] = str[i];
+        }
+    }
+    sec_buf[pos] = '\0';
+    gcry_realloc (sec_buf, g_utf8_strlen(sec_buf, -1) + 1);
+
+    return sec_buf;
+}
